@@ -30,6 +30,7 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <limits.h>
 #include <math.h>
 #include <unistd.h>
 
@@ -836,10 +837,10 @@ solid_picture (MetaDisplay *display,
       return None;
     }
 
-  c.alpha = a * 0xffff;
-  c.red = r * 0xffff;
-  c.green = g * 0xffff;
-  c.blue = b * 0xffff;
+  c.alpha = (unsigned short)(a * USHRT_MAX);
+  c.red   = (unsigned short)(r * USHRT_MAX);
+  c.green = (unsigned short)(g * USHRT_MAX);
+  c.blue  = (unsigned short)(b * USHRT_MAX);
 
   XRenderFillRectangle (xdisplay, PictOpSrc, picture, &c, 0, 0, 1, 1);
   XFreePixmap (xdisplay, pixmap);
@@ -915,7 +916,7 @@ root_tile (MetaScreen *screen)
       c.red = 0x0000;
       c.green = 0x0000;
       c.blue = 0x0000;
-      c.alpha = 0xffff;
+      c.alpha = USHRT_MAX;
 
       XRenderFillRectangle (xdisplay, PictOpSrc, picture, &c, 0, 0, 1, 1);
       XFreePixmap (xdisplay, pixmap);
@@ -1024,6 +1025,19 @@ window_has_shadow (MetaCompWindow *cw)
           return FALSE;
         }
 
+      /* Do not add shadows for left/right tiled windows */
+      if (meta_window_is_tiled_left (cw->window))
+        {
+          meta_verbose ("Window has no shadow because it is tiled left\n");
+          return FALSE;
+        }
+
+      if (meta_window_is_tiled_right (cw->window))
+        {
+          meta_verbose ("Window has no shadow because it is tiled right\n");
+          return FALSE;
+        }
+
       if (meta_window_get_frame (cw->window)) {
         meta_verbose ("Window has shadow because it has a frame\n");
         return TRUE;
@@ -1534,7 +1548,6 @@ paint_windows (MetaScreen   *screen,
         }
     }
 
-
   XFixesSetPictureClipRegion (xdisplay, root_buffer, 0, 0, region);
 
 #ifdef HAVE_PRESENT
@@ -2686,7 +2699,6 @@ process_unmap (MetaCompositorXRender *compositor,
       return;
     }
 
-
   cw = find_window_in_display (compositor->display, event->window);
   if (cw)
     unmap_win (compositor->display, cw->screen, event->window);
@@ -3163,7 +3175,6 @@ xrender_free_window (MetaCompositor *compositor,
 #endif
 }
 
-
 static void
 xrender_process_event (MetaCompositor *compositor,
                        XEvent         *event,
