@@ -23,6 +23,8 @@
  * 02110-1301, USA.
  */
 
+#define _GNU_SOURCE
+
 #include <config.h>
 #include "constraints.h"
 #include "workspace.h"
@@ -447,7 +449,6 @@ setup_constraint_info (ConstraintInfo      *info,
     meta_workspace_get_onxinerama_region (cur_workspace,
                                           xinerama_info->number);
 
-
   /* Log all this information for debugging */
   meta_topic (META_DEBUG_GEOMETRY,
               "Setting up constraint info:\n"
@@ -520,7 +521,6 @@ place_window_if_needed(MetaWindow     *window,
         meta_workspace_get_onxinerama_region (cur_workspace,
                                               xinerama_info->number);
 
-
       info->current.x = placed_rect.x;
       info->current.y = placed_rect.y;
 
@@ -951,7 +951,7 @@ constrain_tiling (MetaWindow         *window,
                        info->resize_gravity,
                        &allow_resize_horizontally,
                        &allow_resize_vertically);
-      
+
       window->tile_resized = TRUE;
     }
 
@@ -972,11 +972,11 @@ constrain_tiling (MetaWindow         *window,
     }
 
   if(!allow_resize_horizontally)
-    {    
+    {
       info->current.x      = target_size.x;
       info->current.width  = target_size.width;
     }
-  
+
   return TRUE;
 }
 
@@ -1327,9 +1327,8 @@ constrain_aspect_ratio (MetaWindow         *window,
                                                       new_width, new_height,
                                                       &best_width, &best_height);
 
-      /* Yeah, I suck for doing implicit rounding -- sue me */
-      new_width  = best_width;
-      new_height = best_height;
+      new_width  = round (best_width);
+      new_height = round (best_height);
 
       break;
     }
