@@ -27,6 +27,8 @@
  */
 
 #include <config.h>
+#include <glib/gi18n-lib.h>
+
 #include "screen-private.h"
 #include "util.h"
 #include "errors.h"
@@ -106,6 +108,7 @@ set_supported_hint (MetaScreen *screen)
 #undef EWMH_ATOMS_ONLY
     screen->display->atom__GTK_FRAME_EXTENTS,
     screen->display->atom__GTK_SHOW_WINDOW_MENU,
+    screen->display->atom__GTK_WORKAREAS
   };
 
   XChangeProperty (screen->display->xdisplay, screen->xroot,
@@ -283,7 +286,6 @@ reload_xinerama_infos (MetaScreen *screen)
               "Marco compiled without Solaris Xinerama support\n");
 #endif /* HAVE_SOLARIS_XINERAMA */
 
-
   /* If no Xinerama, fill in the single screen info so
    * we can use the field unconditionally
    */
@@ -685,7 +687,6 @@ meta_screen_free (MetaScreen *screen,
   if (screen->work_area_idle != 0)
     g_source_remove (screen->work_area_idle);
 
-
   if (XGetGCValues (screen->display->xdisplay,
                     screen->root_xor_gc,
                     GCFont,
@@ -881,7 +882,6 @@ prefs_changed_callback (MetaPreference pref,
     }
 }
 
-
 static char*
 get_screen_name (MetaDisplay *display,
                  int          number)
@@ -1511,12 +1511,12 @@ meta_screen_tile_preview_update_timeout (gpointer data)
   if (window)
     {
       switch (window->tile_mode)
-        {     
+        {
         case META_TILE_MAXIMIZED:
           if (!META_WINDOW_MAXIMIZED (window))
             needs_preview = TRUE;
           break;
-              
+
         case META_TILE_NONE:
           needs_preview = FALSE;
           break;
@@ -2035,6 +2035,48 @@ meta_create_offscreen_window (Display *xdisplay,
                         &attrs);
 }
 
+static void
+set_workspace_work_area_hint (MetaWorkspace *workspace,
+                              MetaScreen    *screen)
+{
+  unsigned long *data;
+  unsigned long *tmp;
+  int i;
+  gchar *workarea_name;
+  Atom workarea_atom;
+
+  data = g_new (unsigned long, screen->n_xinerama_infos * 4);
+  tmp = data;
+
+  for (i = 0; i < screen->n_xinerama_infos; i++)
+    {
+      MetaRectangle area;
+
+      meta_workspace_get_work_area_for_xinerama (workspace, i, &area);
+
+      tmp[0] = area.x;
+      tmp[1] = area.y;
+      tmp[2] = area.width;
+      tmp[3] = area.height;
+
+      tmp += 4;
+    }
+
+  workarea_name = g_strdup_printf ("_GTK_WORKAREAS_D%d",
+                                   meta_workspace_index (workspace));
+
+  workarea_atom = XInternAtom (screen->display->xdisplay, workarea_name, False);
+  g_free (workarea_name);
+
+  meta_error_trap_push (screen->display);
+  XChangeProperty (screen->display->xdisplay, screen->xroot, workarea_atom,
+                   XA_CARDINAL, 32, PropModeReplace,
+                   (guchar*) data, screen->n_xinerama_infos * 4);
+  meta_error_trap_pop (screen->display, TRUE);
+
+  g_free (data);
+}
+
 static void
 set_work_area_hint (MetaScreen *screen)
 {
@@ -2055,6 +2097,7 @@ set_work_area_hint (MetaScreen *screen)
       if (workspace->screen == screen)
         {
           meta_workspace_get_work_area_all_xineramas (workspace, &area);
+          set_workspace_work_area_hint (workspace, screen);
           tmp[0] = area.x;
           tmp[1] = area.y;
           tmp[2] = area.width;
@@ -2104,7 +2147,6 @@ meta_screen_queue_workarea_recalc (MetaScreen *screen)
     }
 }
 
-
 #ifdef WITH_VERBOSE_MODE
 static char *
 meta_screen_corner_to_string (MetaScreenCorner corner)
@@ -2195,7 +2237,6 @@ meta_screen_calc_workspace_layout (MetaScreen          *screen,
    * in the above grids could be missing
    */
 
-
   grid = g_new (int, grid_area);
 
   i = 0;
@@ -2522,7 +2563,6 @@ meta_screen_show_desktop (MetaScreen *screen,
       windows = windows->next;
     }
 
-
   meta_screen_update_showing_desktop_hint (screen);
 }
 
@@ -2539,7 +2579,6 @@ meta_screen_unshow_desktop (MetaScreen *screen)
   meta_screen_update_showing_desktop_hint (screen);
 }
 
-
 #ifdef HAVE_STARTUP_NOTIFICATION
 static gboolean startup_sequence_timeout (void *data);
 
